import { inject, injectable } from "tsyringe";
import { WifiLocationHistoryRepository } from "../repositories/wifiLocationHistoryRepository";

interface CreateWifiLocationHistoryParams {
  mac: string;
  latitude: number;
  longitude: number;
}

interface UpdateWifiLocationHistoryParams {
  mac: string;
  latitude: number;
  longitude: number;
}

@injectable()
export class WifiLocationHistoryService {
  constructor(
    @inject(WifiLocationHistoryRepository)
    private repository: WifiLocationHistoryRepository
  ) {}

  public async getAllWifiLocationHistories() {
    return this.repository.findAll();
  }

  public async getWifiLocationHistoryById(id: string) {
    return this.repository.findById(id);
  }

  public async createWifiLocationHistory(
    data: CreateWifiLocationHistoryParams
  ) {
    const existingEntry = await this.repository.findOne({
      where: {
        mac: data.mac,
      },
      order: [["updated_at_utc", "DESC"]],
    });

    if (
      !existingEntry ||
      existingEntry.latitude !== data.latitude ||
      existingEntry.longitude !== data.longitude
    ) {
      return await this.repository.create(data);
    }

    return existingEntry;
  }
}
